#!/bin/initsh
#
# rc.M		This file is executed by init(8) when the system is being
#		initialized for one of the "multi user" run levels (i.e.
#		levels 1 through 6).  It usually does mounting of file
#		systems et al.
#
# 		Gilbert Ashley <amigo@ibiblio.org> 
#		Use the 'dash' or 'ash' shell

# Tell the viewers what's going to happen.
echo "Going multiuser..."

# save the kernel command line for use later
CMDLINE=`/bin/cat /proc/cmdline`
case $CMDLINE in *'strict'*) STRICT=1 ;; esac

# Update all the shared library links:
if [ '' != "$STRICT" ] ; then
	if [ -x /sbin/ldconfig ] ; then
		echo "Updating shared library links:  /sbin/ldconfig &"
		/sbin/ldconfig &
	fi
fi

# Activate screen blanking if enabled
if [ -x /etc/rc.d/rc.screenblank ] ; then
	. /etc/rc.d/rc.screenblank 
fi

# Set the hostname.
if [ -r /etc/HOSTNAME ] ; then
	/bin/hostname `/bin/cat /etc/HOSTNAME | cut -f1 -d .`
else
	# fall back on this old default:
	echo "darkstar.example.net" > /etc/HOSTNAME
	/bin/hostname darkstar
fi

# Save the contents of 'dmesg':
/bin/dmesg -s 65536 > /var/log/dmesg

# Initialize PCMCIA devices:
if [ -x /etc/rc.d/rc.pcmcia ] ; then
	action=start . /etc/rc.d/rc.pcmcia
	# Allow extra time here for cards to initialize.
	/bin/sleep 5
fi

# Start the system logger.
if [ -x /etc/rc.d/rc.syslog ] && [ -x /usr/sbin/syslogd ] ; then
	action=start . /etc/rc.d/rc.syslog
fi

# Update the X font indexes:
if [ '' != "$STRICT" ] ; then
	if [ -x /usr/bin/fc-cache ] ; then
		echo "Updating X font indexes:  /usr/bin/fc-cache -f &"
		/usr/bin/fc-cache -f &
	fi
fi

# If we are returning from single-user mode we will need to restart
# udevd on systems that use udev:
RUNLEVEL=`/sbin/runlevel`
OLDRUNLEVEL=${RUNLEVEL% *}
if [ "$OLDRUNLEVEL" = '1' ] ; then
	if [ -x /etc/rc.d/rc.udev ] ; then
		if /bin/grep -wq sysfs /proc/mounts ; then
			if ! /bin/grep -wq nohotplug /proc/cmdline ; then
				( action=start . /etc/rc.d/rc.udev & )
			fi
		fi
	fi
fi

# Initialize the networking hardware.
if [ -x /etc/rc.d/rc.inet1 ] ; then
	. /etc/rc.d/rc.inet1
fi

# Look for additional USB/SCSI/IEEE1394/etc devices on multiple LUNs:
if [ -x /etc/rc.d/rc.scanluns ] ; then
	. /etc/rc.d/rc.scanluns
fi

# Start networking daemons:
if [ -x /etc/rc.d/rc.inet2 ] ; then
	. /etc/rc.d/rc.inet2
fi

# Mount any additional filesystem types that haven't already been mounted:
mount -a -v 2> /dev/null | grep -v "already mounted"

# Start the Network Time Protocol daemon:
if [ -x /etc/rc.d/rc.ntpd ] ; then
	action=start . /etc/rc.d/rc.ntpd
fi

# Start APM or ACPI daemon.
# If APM is enabled in the kernel, start apmd:
if [ -r /proc/apm ] ; then
	if [ -x /usr/sbin/apmd ] ; then
		echo "Starting APM daemon:  /usr/sbin/apmd"
		/usr/sbin/apmd
	fi
elif [ -x /etc/rc.d/rc.acpid ] ; then
	action=start . /etc/rc.d/rc.acpid
fi

if [ '' != "$STRICT" ] ; then
	# Update any existing icon cache files:
	(if find /usr/share/icons 2> /dev/null | grep -q icon-theme.cache ; then
		for theme_dir in `/bin/ls /usr/share/icons/* 2> /dev/null` ; do
			if [ -r ${theme_dir}/icon-theme.cache ] ; then
				echo "Updating icon-theme.cache in ${theme_dir}..."
				/usr/bin/gtk-update-icon-cache -t -f ${theme_dir} 1> /dev/null 2> /dev/null &
			fi
		done
		# This would be a large file and probably shouldn't be there.
		if [ -r /usr/share/icons/icon-theme.cache ] ; then
			echo "Deleting icon-theme.cache in /usr/share/icons..."
			#/usr/bin/gtk-update-icon-cache -t -f /usr/share/icons 1> /dev/null 2> /dev/null &
			/bin/rm -f /usr/share/icons/icon-theme.cache
		fi
	fi
	)
	# Update mime database:
	(if [ -x /usr/bin/update-mime-database ] && [ -d /usr/share/mime ] ; then
		echo "Updating MIME database:  /usr/bin/update-mime-database /usr/share/mime &"
		/usr/bin/update-mime-database /usr/share/mime 1> /dev/null 2> /dev/null &
	fi
	)
fi

# Start D-Bus:
if [ -x /etc/rc.d/rc.messagebus ] ; then
	action=start . /etc/rc.d/rc.messagebus
fi

# Start Bluetooth:
if [ -x /etc/rc.d/rc.bluetooth ] ; then
	action=start . /etc/rc.d/rc.bluetooth
fi

# Start wicd:
if [ -x /etc/rc.d/rc.wicd ] ; then
	action=start . /etc/rc.d/rc.wicd
fi

if [ '' != "$STRICT" ] ; then
	# These GTK+/pango files need to be kept up to date for
	# proper input method, pixbuf loaders, and font support.
	(if [ -x /usr/bin/update-gtk-immodules ] ; then
		echo "Updating gtk-immodules"
		/usr/bin/update-gtk-immodules  &
	fi
	if [ -x /usr/bin/update-gdk-pixbuf-loaders ] ; then
		echo "Updating gdk-pixbufloaders"
		/usr/bin/update-gdk-pixbuf-loaders &
	fi
	if [ -x /usr/bin/update-pango-querymodules ] ; then
		echo "Updating pango-querymodules"
		/usr/bin/update-pango-querymodules &
	fi
	)
fi

# Start dnsmasq, a simple DHCP/DNS server:
if [ -x /etc/rc.d/rc.dnsmasq ] ; then
	action=start . /etc/rc.d/rc.dnsmasq
fi

# Start snmpd:
if [ -x /etc/rc.d/rc.snmpd ] ; then
	action=start . /etc/rc.d/rc.snmpd
fi

# Start the print spooling system.  This will usually be LPRng (lpd) or CUPS.
if [ -x /etc/rc.d/rc.cups ] ; then
	# Start CUPS:
	action=start . /etc/rc.d/rc.cups
elif [ -x /etc/rc.d/rc.lprng ] ; then
	# Start LPRng (lpd):
	action=start . /etc/rc.d/rc.lprng
fi

# Start netatalk. (a file/print server for Macs using Appletalk)
if [ -x /etc/rc.d/rc.atalk ] ; then
	. /etc/rc.d/rc.atalk
fi

# Start smartd, which monitors the status of S.M.A.R.T. compatible
# hard drives and reports any problems.  Note some devices (which aren't
# smart, I guess ;) will hang if probed by smartd, so it's commented out
# by default.
#if [ -x /usr/sbin/smartd ] ; then
#  /usr/sbin/smartd
#fi

# If we're using udev, make /dev/cdrom and any other optical drive symlinks
# if some udev rule hasn't made them already:
if [ -x /lib/udev/rc.optical-symlinks ] && [ -x /etc/rc.d/rc.udev ] ; then
		if ! /bin/grep -wq nohotplug /proc/cmdline ; then
			# unknown syntax here, so use 'sh'
			/bin/sh /lib/udev/rc.optical-symlinks
		fi
fi

# Monitor the UPS with genpowerd.
# To use this, uncomment this section and edit your settings in
# /etc/genpowerd.conf (serial device, UPS type, etc).  For more information,
# see "man genpowerd" or the extensive documentation in the
# /usr/doc/genpower-*/ directory.
# You'll also need to configure a similar block in /etc/rc.d/rc.6 if you want
# support for stopping the UPS's inverter after the machine halts.
#if [ -x /sbin/genpowerd ] ; then
#  echo "Starting genpowerd daemon..."
#  /sbin/genpowerd
#fi

# Turn on process accounting.  To enable process accounting, make sure the
# option for BSD process accounting is enabled in your kernel, and then
# create the file /var/log/pacct (touch /var/log/pacct).  By default, process
# accounting is not enabled (since /var/log/pacct does not exist).  This is
# because the log file can get VERY large.
if [ -x /etc/rc.d/rc.accton ] ; then
	. /etc/rc.d/rc.accton
fi

# Start crond (Dillon's crond):
# If you want cron to actually log activity to /var/log/cron, then change
# -l10 to -l8 to increase the logging level.
if [ -x /etc/rc.d/rc.crond ] ; then
	. /etc/rc.d/rc.crond
fi

# Start atd (manages jobs scheduled with 'at'):
if [ -x /etc/rc.d/rc.atd ] ; then
	. /etc/rc.d/rc.atd
fi
# Slackware-Mini-Quota-HOWTO:
# To really activate quotas, you'll need to add 'usrquota' and/or 'grpquota' to
# the appropriate partitions as listed in /etc/fstab.  Here's an example:
#
# /dev/hda2      /home      ext3     defaults,usrquota      1   1
#
# You'll then need to setup initial quota files at the top of the partitions
# to support quota, like this:
# touch /home/aquota.user /home/aquota.group
# chmod 600 /home/aquota.user /home/aquota.group
#
# Then, reboot to activate the system.
# To edit user quotas, use 'edquota'.  See 'man edquota'.  Also, the
# official Quota Mini-HOWTO has lots of useful information.  That can be found
# here:  /usr/doc/Linux-HOWTOs/Quota

# Check quotas and then turn quota system on:
if /bin/grep -q quota /etc/fstab ; then
	for quotafs in `/usr/bin/awk '/quota/ {print $2}' /etc/fstab` ; do
		/bin/rm -f $quotafs/quota.group.new $quotafs/quota.user.new
		/bin/rm -f quotafs/aquota.group.new $quotafs/aquota.user.new
	done
	if [ -x /sbin/quotacheck ] ; then
		echo "Checking filesystem quotas:  /sbin/quotacheck -avugm"
		/sbin/quotacheck -avugm
	fi
	if [ -x /sbin/quotaon ] ; then
		echo "Activating filesystem quotas:  /sbin/quotaon -avug"
		/sbin/quotaon -avug
	fi
fi

# Start the SASL authentication server.  This provides SASL
# authentication services for sendmail:
if [ -x /etc/rc.d/rc.saslauthd ] ; then
	action=start . /etc/rc.d/rc.saslauthd
fi

# Start the sendmail daemon:
if [ -x /etc/rc.d/rc.sendmail ] ; then
	action=start . /etc/rc.d/rc.sendmail
fi

# Load ALSA (sound) defaults:
if [ -x /etc/rc.d/rc.alsa ] ; then
	. /etc/rc.d/rc.alsa
fi

# Load a custom screen font if the user has an rc.font script.
if [ -x /etc/rc.d/rc.font ] ; then
	. /etc/rc.d/rc.font
fi

# Load a custom keymap if the user has an rc.keymap script.
if [ -x /etc/rc.d/rc.keymap ] ; then
	( . /etc/rc.d/rc.keymap )
fi

# Start the MySQL database:
if [ -x /etc/rc.d/rc.mysqld ] ; then
	action=start . /etc/rc.d/rc.mysqld
fi

# Start Apache web server:
if [ -x /etc/rc.d/rc.httpd ] ; then
	action=start . /etc/rc.d/rc.httpd
fi

# Start OpenLDAP:
if [ -x /etc/rc.d/rc.openldap ] ; then
	action=start . /etc/rc.d/rc.openldap
fi

# Start Samba (a file/print server for Win95/NT machines).
# Samba can be started in /etc/inetd.conf instead.
if [ -x /etc/rc.d/rc.samba ] ; then
	action=start . /etc/rc.d/rc.samba
fi

# Start the GPM mouse server:
if [ -x /etc/rc.d/rc.gpm ] ; then
	action=start . /etc/rc.d/rc.gpm
fi

# If there are SystemV init scripts for this runlevel, run them.
if [ -x /etc/rc.d/rc.sysvinit ] ; then
	. /etc/rc.d/rc.sysvinit
fi

# Start the local setup procedure.
if [ -x /etc/rc.d/rc.local ] ; then
	/bin/sh /etc/rc.d/rc.local
fi

# All done.
